#ifndef OMGLOBAL_H_INCLUDED
#define OMGLOBAL_H_INCLUDED

/* reference to qglobal.h */

/**
   The operating system, must be one of: (OM_OS_x)

     MACX	  - Mac OS X
     MAC9	  - Mac OS 9
     MSDOS  - MS-DOS and Windows
     OS2	  - OS/2
     OS2EMX - XFree86 on OS/2 (not PM)
     WIN32  - Win32 (Windows 95/98/ME and Windows NT/2000/XP)
     SUN	  - SunOS
     SOLARIS	 - Sun Solaris
     HPUX	  - HP-UX
     ULTRIX - DEC Ultrix
     LINUX  - Linux
     FREEBSD	 - FreeBSD
     NETBSD - NetBSD
     OPENBSD    - OpenBSD
     BSDI	  - BSD/OS
     IRIX	  - SGI Irix
     OSF	  - Compaq Tru64
     UNIXWARE	 - SCO UnixWare 2
     SCO	  - SCO OpenServer, UnixWare 7, Open UNIX
     AIX	  - AIX
     HURD	  - GNU Hurd
     DGUX	  - DG/UX
     DYNIX  - DYNIX/ptx
     RELIANT	 - Reliant UNIX
     QNX6   - QNX RTP 6.1
     QNX4   - QNX 4.24
     LYNX	  - LynxOS
     BSD4	  - Any BSD 4.4 system
     UNIX	  - Any UNIX BSD/SYSV system
*/

#if defined(__APPLE__) && defined(__GNUC__)
#  define OM_OS_MACX
#elif defined(__MACOSX__)
#  define OM_OS_MACX
#elif defined(macintosh)
#  define OM_OS_MAC9
#elif defined(MSDOS) || defined(_MSDOS) || defined(__MSDOS__)
#  define OM_OS_MSDOS
#elif defined(OS2) || defined(_OS2) || defined(__OS2__)
#  if defined(__EMX__)
#    define OM_OS_OS2EMX
#  else
#    define OM_OS_OS2
#  endif
#elif !defined(SAG_COM) && (defined(WIN64) || defined(_WIN64) || defined(__WIN64__))
#  define OM_OS_WIN32
#  define OM_OS_WIN64
#elif !defined(SAG_COM) && (defined(WIN32) || defined(_WIN32) || defined(__WIN32__) || defined(__NT__))
#  define OM_OS_WIN32
#elif defined(__MWERKS__) && defined(__INTEL__)
#  define OM_OS_WIN32
#elif defined(sun) || defined(__sun) || defined(__sun__)
#  if defined(__SVR4)
#    define OM_OS_SOLARIS
#  else
#    define OM_OS_SUN
#    define OM_OS_BSD4
#  endif
#elif defined(hpux) || defined(__hpux) || defined(__hpux__)
#  define OM_OS_HPUX
#elif defined(ultrix) || defined(__ultrix) || defined(__ultrix__)
#  define OM_OS_ULTRIX
#elif defined(sinix)
#  define OM_OS_RELIANT
#elif defined(linux) || defined(__linux) || defined(__linux__)
#  define OM_OS_LINUX
#elif defined(__FreeBSD__)
#  define OM_OS_FREEBSD
#  define OM_OS_BSD4
#elif defined(__NetBSD__)
#  define OM_OS_NETBSD
#  define OM_OS_BSD4
#elif defined(__OpenBSD__)
#  define OM_OS_OPENBSD
#  define OM_OS_BSD4
#elif defined(bsdi) || defined(__bsdi__)
#  define OM_OS_BSDI
#  define OM_OS_BSD4
#elif defined(sgi) || defined(__sgi)
#  define OM_OS_IRIX
#elif defined(__osf__)
#  define OM_OS_OSF
#elif defined(_AIX)
#  define OM_OS_AIX
#elif defined(__Lynx__)
#  define OM_OS_LYNX
#elif defined(_UNIXWARE)
#  define OM_OS_UNIXWARE
#elif defined(__GNU__)
#  define OM_OS_HURD
#elif defined(DGUX)
#  define OM_OS_DGUX
#elif defined(__QNXNTO__)
#  define OM_OS_QNX6
#elif defined(__QNX__)
#  define OM_OS_QNX4
#elif defined(_SCO_DS) || defined(M_UNIX) || defined(M_XENIX)
#  define OM_OS_SCO
#elif defined(sco) || defined(_UNIXWARE7)
#  define OM_OS_UNIXWARE7
#elif !defined(_SCO_DS) && defined(__USLC__) && defined(__SCO_VERSION__)
#  define OM_OS_UNIXWARE7
#elif defined(_SEQUENT_)
#  define OM_OS_DYNIX
#elif defined(__svr4__)
/*   generic fallback for the rest of svr4 systems, e.g. g++ on UnixWare7.*/
#  define OM_OS_SVR4
#else
#  error "omara has not been ported to this OS - talk to qt-bugs@trolltech.com"
#endif

#if defined(OM_OS_MAC9) || defined(OM_OS_MACX)
#  define OM_OS_MAC
#endif

#if defined(OM_OS_MAC9) || defined(OM_OS_MSDOS) || defined(OM_OS_OS2) || defined(OM_OS_WIN32) || defined(OM_OS_WIN64)
#  undef OM_OS_UNIX
#elif !defined(OM_OS_UNIX)
#  define OM_OS_UNIX
#endif


#endif // OMGLOBAL_H_INCLUDED
